@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -441,7 +441,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def list_hubs(
         self,
-        request: hub.ListHubsRequest = None,
+        request: Union[hub.ListHubsRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -451,7 +451,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Lists hubs in a given project.
 
         Args:
-            request (google.cloud.networkconnectivity_v1.types.ListHubsRequest):
+            request (Union[google.cloud.networkconnectivity_v1.types.ListHubsRequest, dict]):
                 The request object. Request for
                 [HubService.ListHubs][google.cloud.networkconnectivity.v1.HubService.ListHubs]
                 method.
@@ -521,7 +521,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def get_hub(
         self,
-        request: hub.GetHubRequest = None,
+        request: Union[hub.GetHubRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -531,7 +531,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Gets details about the specified hub.
 
         Args:
-            request (google.cloud.networkconnectivity_v1.types.GetHubRequest):
+            request (Union[google.cloud.networkconnectivity_v1.types.GetHubRequest, dict]):
                 The request object. Request for
                 [HubService.GetHub][google.cloud.networkconnectivity.v1.HubService.GetHub]
                 method.
@@ -597,7 +597,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def create_hub(
         self,
-        request: gcn_hub.CreateHubRequest = None,
+        request: Union[gcn_hub.CreateHubRequest, dict] = None,
         *,
         parent: str = None,
         hub: gcn_hub.Hub = None,
@@ -609,7 +609,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Creates a new hub in the specified project.
 
         Args:
-            request (google.cloud.networkconnectivity_v1.types.CreateHubRequest):
+            request (Union[google.cloud.networkconnectivity_v1.types.CreateHubRequest, dict]):
                 The request object. Request for
                 [HubService.CreateHub][google.cloud.networkconnectivity.v1.HubService.CreateHub]
                 method.
@@ -699,7 +699,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def update_hub(
         self,
-        request: gcn_hub.UpdateHubRequest = None,
+        request: Union[gcn_hub.UpdateHubRequest, dict] = None,
         *,
         hub: gcn_hub.Hub = None,
         update_mask: field_mask_pb2.FieldMask = None,
@@ -711,7 +711,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         specified hub.
 
         Args:
-            request (google.cloud.networkconnectivity_v1.types.UpdateHubRequest):
+            request (Union[google.cloud.networkconnectivity_v1.types.UpdateHubRequest, dict]):
                 The request object. Request for
                 [HubService.UpdateHub][google.cloud.networkconnectivity.v1.HubService.UpdateHub]
                 method.
@@ -798,7 +798,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def delete_hub(
         self,
-        request: hub.DeleteHubRequest = None,
+        request: Union[hub.DeleteHubRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -808,7 +808,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Deletes the specified hub.
 
         Args:
-            request (google.cloud.networkconnectivity_v1.types.DeleteHubRequest):
+            request (Union[google.cloud.networkconnectivity_v1.types.DeleteHubRequest, dict]):
                 The request object. The request for
                 [HubService.DeleteHub][google.cloud.networkconnectivity.v1.HubService.DeleteHub].
             name (str):
@@ -890,7 +890,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def list_spokes(
         self,
-        request: hub.ListSpokesRequest = None,
+        request: Union[hub.ListSpokesRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -901,7 +901,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         location.
 
         Args:
-            request (google.cloud.networkconnectivity_v1.types.ListSpokesRequest):
+            request (Union[google.cloud.networkconnectivity_v1.types.ListSpokesRequest, dict]):
                 The request object. The request for
                 [HubService.ListSpokes][google.cloud.networkconnectivity.v1.HubService.ListSpokes].
             parent (str):
@@ -969,7 +969,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def get_spoke(
         self,
-        request: hub.GetSpokeRequest = None,
+        request: Union[hub.GetSpokeRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -979,7 +979,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Gets details about the specified spoke.
 
         Args:
-            request (google.cloud.networkconnectivity_v1.types.GetSpokeRequest):
+            request (Union[google.cloud.networkconnectivity_v1.types.GetSpokeRequest, dict]):
                 The request object. The request for
                 [HubService.GetSpoke][google.cloud.networkconnectivity.v1.HubService.GetSpoke].
             name (str):
@@ -1048,7 +1048,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def create_spoke(
         self,
-        request: hub.CreateSpokeRequest = None,
+        request: Union[hub.CreateSpokeRequest, dict] = None,
         *,
         parent: str = None,
         spoke: hub.Spoke = None,
@@ -1061,7 +1061,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         location.
 
         Args:
-            request (google.cloud.networkconnectivity_v1.types.CreateSpokeRequest):
+            request (Union[google.cloud.networkconnectivity_v1.types.CreateSpokeRequest, dict]):
                 The request object. The request for
                 [HubService.CreateSpoke][google.cloud.networkconnectivity.v1.HubService.CreateSpoke].
             parent (str):
@@ -1156,7 +1156,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def update_spoke(
         self,
-        request: hub.UpdateSpokeRequest = None,
+        request: Union[hub.UpdateSpokeRequest, dict] = None,
         *,
         spoke: hub.Spoke = None,
         update_mask: field_mask_pb2.FieldMask = None,
@@ -1167,7 +1167,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Updates the parameters of the specified spoke.
 
         Args:
-            request (google.cloud.networkconnectivity_v1.types.UpdateSpokeRequest):
+            request (Union[google.cloud.networkconnectivity_v1.types.UpdateSpokeRequest, dict]):
                 The request object. Request for
                 [HubService.UpdateSpoke][google.cloud.networkconnectivity.v1.HubService.UpdateSpoke]
                 method.
@@ -1262,7 +1262,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def delete_spoke(
         self,
-        request: hub.DeleteSpokeRequest = None,
+        request: Union[hub.DeleteSpokeRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1272,7 +1272,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Deletes the specified spoke.
 
         Args:
-            request (google.cloud.networkconnectivity_v1.types.DeleteSpokeRequest):
+            request (Union[google.cloud.networkconnectivity_v1.types.DeleteSpokeRequest, dict]):
                 The request object. The request for
                 [HubService.DeleteSpoke][google.cloud.networkconnectivity.v1.HubService.DeleteSpoke].
             name (str):
