@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -426,7 +426,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def list_hubs(
         self,
-        request: hub.ListHubsRequest = None,
+        request: Union[hub.ListHubsRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -436,7 +436,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Lists Hubs in a given project and location.
 
         Args:
-            request (google.cloud.networkconnectivity_v1alpha1.types.ListHubsRequest):
+            request (Union[google.cloud.networkconnectivity_v1alpha1.types.ListHubsRequest, dict]):
                 The request object. Request for
                 [HubService.ListHubs][google.cloud.networkconnectivity.v1alpha1.HubService.ListHubs]
                 method.
@@ -506,7 +506,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def get_hub(
         self,
-        request: hub.GetHubRequest = None,
+        request: Union[hub.GetHubRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -516,7 +516,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Gets details of a single Hub.
 
         Args:
-            request (google.cloud.networkconnectivity_v1alpha1.types.GetHubRequest):
+            request (Union[google.cloud.networkconnectivity_v1alpha1.types.GetHubRequest, dict]):
                 The request object. Request for
                 [HubService.GetHub][google.cloud.networkconnectivity.v1alpha1.HubService.GetHub]
                 method.
@@ -583,7 +583,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def create_hub(
         self,
-        request: gcn_hub.CreateHubRequest = None,
+        request: Union[gcn_hub.CreateHubRequest, dict] = None,
         *,
         parent: str = None,
         hub: gcn_hub.Hub = None,
@@ -595,7 +595,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Creates a new Hub in a given project and location.
 
         Args:
-            request (google.cloud.networkconnectivity_v1alpha1.types.CreateHubRequest):
+            request (Union[google.cloud.networkconnectivity_v1alpha1.types.CreateHubRequest, dict]):
                 The request object. Request for
                 [HubService.CreateHub][google.cloud.networkconnectivity.v1alpha1.HubService.CreateHub]
                 method.
@@ -688,7 +688,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def update_hub(
         self,
-        request: gcn_hub.UpdateHubRequest = None,
+        request: Union[gcn_hub.UpdateHubRequest, dict] = None,
         *,
         hub: gcn_hub.Hub = None,
         update_mask: field_mask_pb2.FieldMask = None,
@@ -699,7 +699,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Updates the parameters of a single Hub.
 
         Args:
-            request (google.cloud.networkconnectivity_v1alpha1.types.UpdateHubRequest):
+            request (Union[google.cloud.networkconnectivity_v1alpha1.types.UpdateHubRequest, dict]):
                 The request object. Request for
                 [HubService.UpdateHub][google.cloud.networkconnectivity.v1alpha1.HubService.UpdateHub]
                 method.
@@ -787,7 +787,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def delete_hub(
         self,
-        request: hub.DeleteHubRequest = None,
+        request: Union[hub.DeleteHubRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -797,7 +797,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Deletes a single Hub.
 
         Args:
-            request (google.cloud.networkconnectivity_v1alpha1.types.DeleteHubRequest):
+            request (Union[google.cloud.networkconnectivity_v1alpha1.types.DeleteHubRequest, dict]):
                 The request object. The request for
                 [HubService.DeleteHub][google.cloud.networkconnectivity.v1alpha1.HubService.DeleteHub].
             name (str):
@@ -879,7 +879,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def list_spokes(
         self,
-        request: hub.ListSpokesRequest = None,
+        request: Union[hub.ListSpokesRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -889,7 +889,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Lists Spokes in a given project and location.
 
         Args:
-            request (google.cloud.networkconnectivity_v1alpha1.types.ListSpokesRequest):
+            request (Union[google.cloud.networkconnectivity_v1alpha1.types.ListSpokesRequest, dict]):
                 The request object. The request for
                 [HubService.ListSpokes][google.cloud.networkconnectivity.v1alpha1.HubService.ListSpokes].
             parent (str):
@@ -957,7 +957,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def get_spoke(
         self,
-        request: hub.GetSpokeRequest = None,
+        request: Union[hub.GetSpokeRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -967,7 +967,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Gets details of a single Spoke.
 
         Args:
-            request (google.cloud.networkconnectivity_v1alpha1.types.GetSpokeRequest):
+            request (Union[google.cloud.networkconnectivity_v1alpha1.types.GetSpokeRequest, dict]):
                 The request object. The request for
                 [HubService.GetSpoke][google.cloud.networkconnectivity.v1alpha1.HubService.GetSpoke].
             name (str):
@@ -1029,7 +1029,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def create_spoke(
         self,
-        request: hub.CreateSpokeRequest = None,
+        request: Union[hub.CreateSpokeRequest, dict] = None,
         *,
         parent: str = None,
         spoke: hub.Spoke = None,
@@ -1041,7 +1041,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Creates a new Spoke in a given project and location.
 
         Args:
-            request (google.cloud.networkconnectivity_v1alpha1.types.CreateSpokeRequest):
+            request (Union[google.cloud.networkconnectivity_v1alpha1.types.CreateSpokeRequest, dict]):
                 The request object. The request for
                 [HubService.CreateSpoke][google.cloud.networkconnectivity.v1alpha1.HubService.CreateSpoke].
             parent (str):
@@ -1132,7 +1132,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def update_spoke(
         self,
-        request: hub.UpdateSpokeRequest = None,
+        request: Union[hub.UpdateSpokeRequest, dict] = None,
         *,
         spoke: hub.Spoke = None,
         update_mask: field_mask_pb2.FieldMask = None,
@@ -1143,7 +1143,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Updates the parameters of a single Spoke.
 
         Args:
-            request (google.cloud.networkconnectivity_v1alpha1.types.UpdateSpokeRequest):
+            request (Union[google.cloud.networkconnectivity_v1alpha1.types.UpdateSpokeRequest, dict]):
                 The request object. Request for
                 [HubService.UpdateSpoke][google.cloud.networkconnectivity.v1alpha1.HubService.UpdateSpoke]
                 method.
@@ -1232,7 +1232,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     def delete_spoke(
         self,
-        request: hub.DeleteSpokeRequest = None,
+        request: Union[hub.DeleteSpokeRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1242,7 +1242,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Deletes a single Spoke.
 
         Args:
-            request (google.cloud.networkconnectivity_v1alpha1.types.DeleteSpokeRequest):
+            request (Union[google.cloud.networkconnectivity_v1alpha1.types.DeleteSpokeRequest, dict]):
                 The request object. The request for
                 [HubService.DeleteSpoke][google.cloud.networkconnectivity.v1alpha1.HubService.DeleteSpoke].
             name (str):
